@@ -266,8 +266,10 @@ def cleaninput(args):
 #  @param args Namespace of arguments
 #  @return CLIinput.inp (file name)
 def parseCLI(args):
+    print(args)
     cliargs = ' '.join(args)
-    s = filter(None,cliargs.split('-'))
+    cliargs = ' ' + cliargs   
+    s = filter(None,cliargs.split(' -'))
     fname = 'CLIinput.inp'
     f = open(fname,'w')
     f.write('# molSimplify input file generated from CLI input\n')
@@ -298,6 +300,7 @@ def parseinputfile(args):
         li = line.strip()
         li = li.replace('\n','')
         line = line.replace('\n','')
+        print(line)
         if not li.startswith("#") and len(li)>0: # ignore comments/empty lines
             # split arguments on whitespace, commas (this breaks smarts)
             l = filter(None,re.split(' |\t|,|&',li))
